==> peony_3.0.1.orig.tar.gz: peony/translations/peony-qt-desktop/peony-qt-desktop_tr.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="tr_TR">
<context>
    <name>Peony::DesktopIconView</name>
    <message>
        <location filename="../../peony-qt-desktop/desktop-icon-view.h" line="72"/>
        <source>Desktop Icon View</source>
        <translation>Masaüstü Simgelerini Göster</translation>
    </message>
    <message>
        <location filename="../../peony-qt-desktop/desktop-icon-view.cpp" line="354"/>
        <source>New Folder</source>
        <translation>Yeni Klasör</translation>
    </message>
    <message>
        <location filename="../../peony-qt-desktop/desktop-icon-view.cpp" line="429"/>
        <source>set background</source>
        <translation>Arkaplanı Değiştir</translation>
    </message>
</context>
<context>
    <name>Peony::DesktopMenu</name>
    <message>
        <location filename="../../peony-qt-desktop/desktop-menu.cpp" line="106"/>
        <source>&amp;Open in new Window</source>
        <translation>Yeni Pencerede Aç(&amp;N)</translation>
    </message>
    <message>
        <location filename="../../peony-qt-desktop/desktop-menu.cpp" line="111"/>
        <source>Select &amp;All</source>
        <translation>Tümünü Seç</translation>
    </message>
    <message>
        <location filename="../../peony-qt-desktop/desktop-menu.cpp" line="130"/>
        <location filename="../../peony-qt-desktop/desktop-menu.cpp" line="154"/>
        <source>&amp;Open &quot;%1&quot;</source>
        <translation>&quot;%1&quot; Aç</translation>
    </message>
    <message>
        <location filename="../../peony-qt-desktop/desktop-menu.cpp" line="135"/>
        <source>Open &quot;%1&quot; &amp;with...</source>
        <translation>&quot;%1&quot; &amp;ile aç...</translation>
    </message>
    <message>
        <location filename="../../peony-qt-desktop/desktop-menu.cpp" line="148"/>
        <location filename="../../peony-qt-desktop/desktop-menu.cpp" line="173"/>
        <source>&amp;More applications...</source>
        <translation>&amp;Daha fazla uygulama...</translation>
    </message>
    <message>
        <location filename="../../peony-qt-desktop/desktop-menu.cpp" line="159"/>
        <source>Open &quot;%1&quot; with...</source>
        <translation>&quot;%1&quot; ile aç...</translation>
    </message>
    <message>
        <location filename="../../peony-qt-desktop/desktop-menu.cpp" line="179"/>
        <source>&amp;Open</source>
        <translation>&amp;Aç</translation>
    </message>
    <message>
        <location filename="../../peony-qt-desktop/desktop-menu.cpp" line="186"/>
        <source>&amp;Open %1 selected files</source>
        <translation>Seçilen %1 dosyasını aç</translation>
    </message>
    <message>
        <location filename="../../peony-qt-desktop/desktop-menu.cpp" line="209"/>
        <source>Reverse Select</source>
        <translation>Seçimi Ters Çevir</translation>
    </message>
    <message>
        <location filename="../../peony-qt-desktop/desktop-menu.cpp" line="223"/>
        <source>&amp;New...</source>
        <translation>&amp;Yeni...</translation>
    </message>
    <message>
        <location filename="../../peony-qt-desktop/desktop-menu.cpp" line="249"/>
        <source>Empty &amp;File</source>
        <translation>&amp;Boş Dosya</translation>
    </message>
    <message>
        <location filename="../../peony-qt-desktop/desktop-menu.cpp" line="259"/>
        <source>&amp;Folder</source>
        <translation>&amp;Klasör</translation>
    </message>
    <message>
        <location filename="../../peony-qt-desktop/desktop-menu.cpp" line="263"/>
        <source>New Folder</source>
        <translation>Yeni Klasör</translation>
    </message>
    <message>
        <location filename="../../peony-qt-desktop/desktop-menu.cpp" line="280"/>
        <source>View Type...</source>
        <translation>Görünüm Türü...</translation>
    </message>
    <message>
        <location filename="../../peony-qt-desktop/desktop-menu.cpp" line="286"/>
        <source>&amp;Small</source>
        <translation>&amp;Küçük</translation>
    </message>
    <message>
        <location filename="../../peony-qt-desktop/desktop-menu.cpp" line="289"/>
        <source>&amp;Normal</source>
        <translation>&amp;Normal</translation>
    </message>
    <message>
        <location filename="../../peony-qt-desktop/desktop-menu.cpp" line="292"/>
        <source>&amp;Large</source>
        <translation>&amp;Büyük</translation>
    </message>
    <message>
        <location filename="../../peony-qt-desktop/desktop-menu.cpp" line="295"/>
        <source>&amp;Huge</source>
        <translation>&amp;Daha Büyük</translation>
    </message>
    <message>
        <location filename="../../peony-qt-desktop/desktop-menu.cpp" line="323"/>
        <source>Sort By...</source>
        <translation>Sırala...</translation>
    </message>
    <message>
        <location filename="../../peony-qt-desktop/desktop-menu.cpp" line="328"/>
        <source>Name</source>
        <translation>İsim</translation>
    </message>
    <message>
        <location filename="../../peony-qt-desktop/desktop-menu.cpp" line="329"/>
        <source>File Type</source>
        <translation>Dosya Türü</translation>
    </message>
    <message>
        <location filename="../../peony-qt-desktop/desktop-menu.cpp" line="330"/>
        <source>File Size</source>
        <translation>Dosya Boyutu</translation>
    </message>
    <message>
        <location filename="../../peony-qt-desktop/desktop-menu.cpp" line="331"/>
        <source>Modified Date</source>
        <translation>Düzenleme Tarihi</translation>
    </message>
    <message>
        <location filename="../../peony-qt-desktop/desktop-menu.cpp" line="420"/>
        <source>&amp;Delete to trash</source>
        <translation>Çöp Kutusuna Taşı</translation>
    </message>
    <message>
        <location filename="../../peony-qt-desktop/desktop-menu.cpp" line="425"/>
        <source>Delete forever</source>
        <translation>Kalıcı olarak sil</translation>
    </message>
    <message>
        <location filename="../../peony-qt-desktop/desktop-menu.cpp" line="459"/>
        <source>P&amp;roperties</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Sort Order...</source>
        <translation type="vanished">Sıralama Düzeni...</translation>
    </message>
    <message>
        <source>Ascending Order</source>
        <translation type="vanished">Artan Düzen</translation>
    </message>
    <message>
        <source>Descending Order</source>
        <translation type="vanished">Azalan Düzen</translation>
    </message>
    <message>
        <source>Zoom &amp;In</source>
        <translation type="vanished">Yakınlaştır</translation>
    </message>
    <message>
        <source>Zoom &amp;Out</source>
        <translation type="vanished">Uzaklaştır</translation>
    </message>
    <message>
        <location filename="../../peony-qt-desktop/desktop-menu.cpp" line="393"/>
        <source>&amp;Restore all</source>
        <translation>Tümünü Onar</translation>
    </message>
    <message>
        <location filename="../../peony-qt-desktop/desktop-menu.cpp" line="397"/>
        <source>&amp;Clean the trash</source>
        <translation>Çöpü Temizle</translation>
    </message>
    <message>
        <location filename="../../peony-qt-desktop/desktop-menu.cpp" line="398"/>
        <source>Delete Permanently</source>
        <translation>Kalıcı Olarak Sil</translation>
    </message>
    <message>
        <location filename="../../peony-qt-desktop/desktop-menu.cpp" line="398"/>
        <source>Are you sure that you want to delete these files? Once you start a deletion, the files deleting will never be restored again.</source>
        <translation>Bu dosyaları silmek istediğinizden emin misiniz? Bir silme işlemini başlattığınızda, silinen dosyalar bir daha geri yüklenmeyecektir.</translation>
    </message>
    <message>
        <location filename="../../peony-qt-desktop/desktop-menu.cpp" line="410"/>
        <source>&amp;Copy</source>
        <translation>&amp;Kopyala</translation>
    </message>
    <message>
        <location filename="../../peony-qt-desktop/desktop-menu.cpp" line="414"/>
        <source>Cu&amp;t</source>
        <translation>Kes</translation>
    </message>
    <message>
        <source>&amp;Delete</source>
        <translation type="vanished">Sil</translation>
    </message>
    <message>
        <location filename="../../peony-qt-desktop/desktop-menu.cpp" line="432"/>
        <source>&amp;Rename</source>
        <translation>Yeniden Adlandır</translation>
    </message>
    <message>
        <location filename="../../peony-qt-desktop/desktop-menu.cpp" line="439"/>
        <source>&amp;Paste</source>
        <translation>Yapıştır</translation>
    </message>
    <message>
        <location filename="../../peony-qt-desktop/desktop-menu.cpp" line="445"/>
        <source>&amp;Refresh</source>
        <translation>Yenile</translation>
    </message>
    <message>
        <source>&amp;Properties</source>
        <translation type="vanished">Özellikler</translation>
    </message>
</context>
<context>
    <name>Peony::DesktopWindow</name>
    <message>
        <location filename="../../peony-qt-desktop/desktop-window.cpp" line="91"/>
        <source>Desktop</source>
        <translation>Masaüstü</translation>
    </message>
    <message>
        <location filename="../../peony-qt-desktop/desktop-window.cpp" line="156"/>
        <source>set background</source>
        <translation>Arkaplanı Değiştir</translation>
    </message>
    <message>
        <location filename="../../peony-qt-desktop/desktop-window.cpp" line="527"/>
        <source>New Folder</source>
        <translation>Yeni Klasör</translation>
    </message>
</context>
<context>
    <name>PeonyDesktopApplication</name>
    <message>
        <source>Close the peony-qt desktop window</source>
        <translation type="vanished">Masaüstünü kapatın ve çıkın</translation>
    </message>
    <message>
        <source>peony-qt-desktop</source>
        <translation type="vanished">Masaüstü</translation>
    </message>
    <message>
        <source>Peony-Qt Desktop</source>
        <translation type="vanished">Masaüstü</translation>
    </message>
    <message>
        <source>Desktop</source>
        <translation type="vanished">Masaüstü</translation>
    </message>
    <message>
        <location filename="../../peony-qt-desktop/peony-desktop-application.cpp" line="206"/>
        <source>Close the peony desktop window</source>
        <translation>Peony masaüstü penceresini kapat</translation>
    </message>
    <message>
        <location filename="../../peony-qt-desktop/peony-desktop-application.cpp" line="209"/>
        <source>Take over the dbus service.</source>
        <translation>Dbus servisini al</translation>
    </message>
    <message>
        <location filename="../../peony-qt-desktop/peony-desktop-application.cpp" line="212"/>
        <source>Take over the desktop displaying</source>
        <translation>Masaüstü görüntülemeyi al</translation>
    </message>
</context>
</TS>

==> peony_3.0.2.orig.tar.gz: peony/translations/peony-qt-desktop/peony-qt-desktop_tr.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="tr_TR">
<context>
    <name>Peony::DesktopIconView</name>
    <message>
        <location filename="../../peony-qt-desktop/desktop-icon-view.h" line="72"/>
        <source>Desktop Icon View</source>
        <translation>Masaüstü Simgelerini Göster</translation>
    </message>
    <message>
        <location filename="../../peony-qt-desktop/desktop-icon-view.cpp" line="354"/>
        <source>New Folder</source>
        <translation>Yeni Klasör</translation>
    </message>
    <message>
        <location filename="../../peony-qt-desktop/desktop-icon-view.cpp" line="429"/>
        <source>set background</source>
        <translation>Arkaplanı Değiştir</translation>
    </message>
</context>
<context>
    <name>Peony::DesktopMenu</name>
    <message>
        <location filename="../../peony-qt-desktop/desktop-menu.cpp" line="106"/>
        <source>&amp;Open in new Window</source>
        <translation>Yeni Pencerede Aç</translation>
    </message>
    <message>
        <location filename="../../peony-qt-desktop/desktop-menu.cpp" line="111"/>
        <source>Select &amp;All</source>
        <translation>Tümünü Seç</translation>
    </message>
    <message>
        <location filename="../../peony-qt-desktop/desktop-menu.cpp" line="130"/>
        <location filename="../../peony-qt-desktop/desktop-menu.cpp" line="154"/>
        <source>&amp;Open &quot;%1&quot;</source>
        <translation>&quot;%1&quot; Aç</translation>
    </message>
    <message>
        <location filename="../../peony-qt-desktop/desktop-menu.cpp" line="135"/>
        <source>Open &quot;%1&quot; &amp;with...</source>
        <translation>&quot;%1&quot; &amp;ile aç...</translation>
    </message>
    <message>
        <location filename="../../peony-qt-desktop/desktop-menu.cpp" line="148"/>
        <location filename="../../peony-qt-desktop/desktop-menu.cpp" line="173"/>
        <source>&amp;More applications...</source>
        <translation>&amp;Daha fazla uygulama...</translation>
    </message>
    <message>
        <location filename="../../peony-qt-desktop/desktop-menu.cpp" line="159"/>
        <source>Open &quot;%1&quot; with...</source>
        <translation>&quot;%1&quot; ile aç...</translation>
    </message>
    <message>
        <location filename="../../peony-qt-desktop/desktop-menu.cpp" line="179"/>
        <source>&amp;Open</source>
        <translation>&amp;Aç</translation>
    </message>
    <message>
        <location filename="../../peony-qt-desktop/desktop-menu.cpp" line="186"/>
        <source>&amp;Open %1 selected files</source>
        <translation>Seçilen %1 dosyasını aç</translation>
    </message>
    <message>
        <location filename="../../peony-qt-desktop/desktop-menu.cpp" line="209"/>
        <source>Reverse Select</source>
        <translation>Seçimi Ters Çevir</translation>
    </message>
    <message>
        <location filename="../../peony-qt-desktop/desktop-menu.cpp" line="223"/>
        <source>&amp;New...</source>
        <translation>&amp;Yeni...</translation>
    </message>
    <message>
        <location filename="../../peony-qt-desktop/desktop-menu.cpp" line="249"/>
        <source>Empty &amp;File</source>
        <translation>&amp;Boş Dosya</translation>
    </message>
    <message>
        <location filename="../../peony-qt-desktop/desktop-menu.cpp" line="259"/>
        <source>&amp;Folder</source>
        <translation>&amp;Klasör</translation>
    </message>
    <message>
        <location filename="../../peony-qt-desktop/desktop-menu.cpp" line="263"/>
        <source>New Folder</source>
        <translation>Yeni Klasör</translation>
    </message>
    <message>
        <location filename="../../peony-qt-desktop/desktop-menu.cpp" line="280"/>
        <source>View Type...</source>
        <translation>Görünüm Türü...</translation>
    </message>
    <message>
        <location filename="../../peony-qt-desktop/desktop-menu.cpp" line="286"/>
        <source>&amp;Small</source>
        <translation>&amp;Küçük</translation>
    </message>
    <message>
        <location filename="../../peony-qt-desktop/desktop-menu.cpp" line="289"/>
        <source>&amp;Normal</source>
        <translation>&amp;Normal</translation>
    </message>
    <message>
        <location filename="../../peony-qt-desktop/desktop-menu.cpp" line="292"/>
        <source>&amp;Large</source>
        <translation>&amp;Büyük</translation>
    </message>
    <message>
        <location filename="../../peony-qt-desktop/desktop-menu.cpp" line="295"/>
        <source>&amp;Huge</source>
        <translation>&amp;Daha Büyük</translation>
    </message>
    <message>
        <location filename="../../peony-qt-desktop/desktop-menu.cpp" line="323"/>
        <source>Sort By...</source>
        <translation>Sırala...</translation>
    </message>
    <message>
        <location filename="../../peony-qt-desktop/desktop-menu.cpp" line="328"/>
        <source>Name</source>
        <translation>İsim</translation>
    </message>
    <message>
        <location filename="../../peony-qt-desktop/desktop-menu.cpp" line="329"/>
        <source>File Type</source>
        <translation>Dosya Türü</translation>
    </message>
    <message>
        <location filename="../../peony-qt-desktop/desktop-menu.cpp" line="330"/>
        <source>File Size</source>
        <translation>Dosya Boyutu</translation>
    </message>
    <message>
        <location filename="../../peony-qt-desktop/desktop-menu.cpp" line="331"/>
        <source>Modified Date</source>
        <translation>Düzenleme Tarihi</translation>
    </message>
    <message>
        <location filename="../../peony-qt-desktop/desktop-menu.cpp" line="420"/>
        <source>&amp;Delete to trash</source>
        <translation>Çöp Kutusuna Taşı</translation>
    </message>
    <message>
        <location filename="../../peony-qt-desktop/desktop-menu.cpp" line="425"/>
        <source>Delete forever</source>
        <translation>Kalıcı olarak sil</translation>
    </message>
    <message>
        <location filename="../../peony-qt-desktop/desktop-menu.cpp" line="459"/>
        <source>P&amp;roperties</source>
        <translation type="unfinished">Özellikler</translation>
    </message>
    <message>
        <source>Sort Order...</source>
        <translation type="vanished">Sıralama Düzeni...</translation>
    </message>
    <message>
        <source>Ascending Order</source>
        <translation type="vanished">Artan Düzen</translation>
    </message>
    <message>
        <source>Descending Order</source>
        <translation type="vanished">Azalan Düzen</translation>
    </message>
    <message>
        <source>Zoom &amp;In</source>
        <translation type="vanished">Yakınlaştır</translation>
    </message>
    <message>
        <source>Zoom &amp;Out</source>
        <translation type="vanished">Uzaklaştır</translation>
    </message>
    <message>
        <location filename="../../peony-qt-desktop/desktop-menu.cpp" line="393"/>
        <source>&amp;Restore all</source>
        <translation>Tümünü Onar</translation>
    </message>
    <message>
        <location filename="../../peony-qt-desktop/desktop-menu.cpp" line="397"/>
        <source>&amp;Clean the trash</source>
        <translation>Çöpü Temizle</translation>
    </message>
    <message>
        <location filename="../../peony-qt-desktop/desktop-menu.cpp" line="398"/>
        <source>Delete Permanently</source>
        <translation>Kalıcı Olarak Sil</translation>
    </message>
    <message>
        <location filename="../../peony-qt-desktop/desktop-menu.cpp" line="398"/>
        <source>Are you sure that you want to delete these files? Once you start a deletion, the files deleting will never be restored again.</source>
        <translation>Bu dosyaları silmek istediğinizden emin misiniz? Bir silme işlemini başlattığınızda, silinen dosyalar bir daha geri yüklenmeyecektir.</translation>
    </message>
    <message>
        <location filename="../../peony-qt-desktop/desktop-menu.cpp" line="410"/>
        <source>&amp;Copy</source>
        <translation>&amp;Kopyala</translation>
    </message>
    <message>
        <location filename="../../peony-qt-desktop/desktop-menu.cpp" line="414"/>
        <source>Cu&amp;t</source>
        <translation>Kes</translation>
    </message>
    <message>
        <source>&amp;Delete</source>
        <translation type="vanished">Sil</translation>
    </message>
    <message>
        <location filename="../../peony-qt-desktop/desktop-menu.cpp" line="432"/>
        <source>&amp;Rename</source>
        <translation>Yeniden Adlandır</translation>
    </message>
    <message>
        <location filename="../../peony-qt-desktop/desktop-menu.cpp" line="439"/>
        <source>&amp;Paste</source>
        <translation>Yapıştır</translation>
    </message>
    <message>
        <location filename="../../peony-qt-desktop/desktop-menu.cpp" line="445"/>
        <source>&amp;Refresh</source>
        <translation>Yenile</translation>
    </message>
    <message>
        <source>&amp;Properties</source>
        <translation type="vanished">Özellikler</translation>
    </message>
</context>
<context>
    <name>Peony::DesktopWindow</name>
    <message>
        <location filename="../../peony-qt-desktop/desktop-window.cpp" line="91"/>
        <source>Desktop</source>
        <translation>Masaüstü</translation>
    </message>
    <message>
        <location filename="../../peony-qt-desktop/desktop-window.cpp" line="156"/>
        <source>set background</source>
        <translation>Arkaplanı Değiştir</translation>
    </message>
    <message>
        <location filename="../../peony-qt-desktop/desktop-window.cpp" line="527"/>
        <source>New Folder</source>
        <translation>Yeni Klasör</translation>
    </message>
</context>
<context>
    <name>PeonyDesktopApplication</name>
    <message>
        <source>Close the peony-qt desktop window</source>
        <translation type="vanished">Masaüstünü kapatın ve çıkın</translation>
    </message>
    <message>
        <source>peony-qt-desktop</source>
        <translation type="vanished">Masaüstü</translation>
    </message>
    <message>
        <source>Peony-Qt Desktop</source>
        <translation type="vanished">Masaüstü</translation>
    </message>
    <message>
        <source>Desktop</source>
        <translation type="vanished">Masaüstü</translation>
    </message>
    <message>
        <location filename="../../peony-qt-desktop/peony-desktop-application.cpp" line="206"/>
        <source>Close the peony desktop window</source>
        <translation>Peony masaüstü penceresini kapat</translation>
    </message>
    <message>
        <location filename="../../peony-qt-desktop/peony-desktop-application.cpp" line="209"/>
        <source>Take over the dbus service.</source>
        <translation>Dbus servisini al</translation>
    </message>
    <message>
        <location filename="../../peony-qt-desktop/peony-desktop-application.cpp" line="212"/>
        <source>Take over the desktop displaying</source>
        <translation>Masaüstü görüntülemeyi al</translation>
    </message>
</context>
</TS>
